from ase.optimize import FIRE
from gpaw import GPAW, FermiDirac, Mixer, PoissonSolver
from ase.io import read
from ase.visualize import view
from gpaw.utilities import h2gpts
from gpaw.xc.libvdwxc import vdw_df_cx

system = read('quim.pdb')
system.pbc = 1

calc = GPAW(mode='lcao',
            gpts=h2gpts(0.2, system.cell, idiv=8),
            txt='gpaw.txt',
            xc=vdw_df_cx(),
            mixer=Mixer(0.2, 5, 50.0),
            parallel=dict(sl_auto=True),
            nbands='105%',
            poissonsolver=PoissonSolver(relax='GS'),
            occupations=FermiDirac(0.1),
            basis='dzp')

opt = FIRE(system, trajectory='opt.traj',
           logfile='opt.log')

system.calc = calc

opt.run(fmax=0.05)
